==> haskell-uri-bytestring-0.3.3.1-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uri-bytestring
version:              0.3.3.1
visibility:           public
id:                   uri-bytestring-0.3.3.1-3eA0phktBJe2kApCg2aE2i
key:                  uri-bytestring-0.3.3.1-3eA0phktBJe2kApCg2aE2i
license:              BSD-3-Clause
copyright:            Soostone Inc.
maintainer:           Michael Xavier <michael.xavier@soostone.com>
author:               Doug Beardsley, Michael Xavier
homepage:             https://github.com/Soostone/uri-bytestring
synopsis:             Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.

category:             Web
abi:                  8e4f434fd52cae03f3d03c0f20bdfdf2
exposed:              True
exposed-modules:      URI.ByteString URI.ByteString.QQ
hidden-modules:
    URI.ByteString.Lens URI.ByteString.Types URI.ByteString.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/uri-bytestring-0.3.3.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/uri-bytestring-0.3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring
hs-libraries:         HSuri-bytestring-0.3.3.1-3eA0phktBJe2kApCg2aE2i
depends:
    attoparsec-0.14.4-KcORgxsqlxoJMIXhUYAkBQ base-4.15.1.0
    blaze-builder-0.4.2.3-D7RNQqfFzoeIMP5JYaknz9 bytestring-0.10.12.1
    containers-0.6.4.1 template-haskell-2.17.0.0
    th-lift-instances-0.1.20-3rMV7YSq8vQHhrf2LmGlnv

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-0.3.3.1-171-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uri-bytestring
version:              0.3.3.1
visibility:           public
id:                   uri-bytestring-0.3.3.1-1KWxlU78N0RLnTWileF4rR
key:                  uri-bytestring-0.3.3.1-1KWxlU78N0RLnTWileF4rR
license:              BSD-3-Clause
copyright:            Soostone Inc.
maintainer:           Michael Xavier <michael.xavier@soostone.com>
author:               Doug Beardsley, Michael Xavier
homepage:             https://github.com/Soostone/uri-bytestring
synopsis:             Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.

category:             Web
abi:                  b8ba3d4ed08b19d87ce8d9c48c30f574
exposed:              True
exposed-modules:      URI.ByteString URI.ByteString.QQ
hidden-modules:
    URI.ByteString.Lens URI.ByteString.Types URI.ByteString.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/uri-bytestring-0.3.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/uri-bytestring-0.3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring
hs-libraries:         HSuri-bytestring-0.3.3.1-1KWxlU78N0RLnTWileF4rR
depends:
    attoparsec-0.14.4-6bGZjP6ZyLf9ECb8I9ykxo base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    containers-0.6.5.1 template-haskell-2.18.0.0
    th-lift-instances-0.1.20-7weh2RpRvyi2KLECntdptN

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
